@@ -36,6 +36,13 @@ GpsPos::GpsPos(QObject *parent) :
         source->startUpdates();
     }
 }
+//call for convert
+GpsPos::GpsPos(QObject *parent, QString logmethod) :
+    QObject(parent)
+{
+    writegpxdata();
+}
+
 //call for last known value
 GpsPos::GpsPos(QObject *parent, bool fout, QString posm, bool date, bool time) :
     QObject(parent)
@@ -57,7 +64,7 @@ GpsPos::GpsPos(QObject *parent, bool fout, QString posm, bool date, bool time) :
     }
 }
 // call for loop
-GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat, bool fout, QString posm, int interval, bool date, bool time, QString logmethod) :
+GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat, bool fout, QString posm, int interval, bool date, bool time, QString logmethod, bool newtrack) :
     QObject(parent)
 {
     g_run=0;
@@ -67,10 +74,10 @@ GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat,
     log_method=logmethod;
     b_date=date;
     b_time=time;
-    //bool show_sat=showsat;
+
     m_console = new ConsoleReader(this);
     connect(m_console, SIGNAL(textReceived(QString)), this, SLOT(quit(QString)));
-
+    if (newtrack) writelogfile("newtrack");
 
     QGeoPositionInfoSource *source = QGeoPositionInfoSource::createDefaultSource(this);
     if (interval!=0) source->setUpdateInterval(interval);
@@ -244,8 +251,8 @@ void GpsPos::writelogfile(QString line)
 
 void GpsPos::writegpxdata()
 {
-    //lat = static_cast<double>(static_cast<int>(lat*100+0.5))/100.0;
-    //lon = static_cast<double>(static_cast<int>(lon*100+0.5))/100.0;
+    QTextStream cout(stdout);
+
     QDir userdir=QDir::homePath();
     QFile file(userdir.absolutePath()+"/gpscon.gpx");
     QFile logfile(userdir.absolutePath()+"/gpscon.log");
@@ -257,6 +264,8 @@ void GpsPos::writegpxdata()
         return;
     }
     qDebug() << "writing gpx file: " << file.fileName() + " ...";
+    int tloglines=0;
+    int tgpxlines=0;
     QXmlStreamWriter xmlWriter(&file);
     xmlWriter.setAutoFormatting(true);
     xmlWriter.writeStartDocument();
@@ -269,52 +278,61 @@ void GpsPos::writegpxdata()
 
     while(!in.atEnd())
     {
+        tloglines++;
         QString line = in.readLine();
-        QStringList value = line.split(QRegExp(";"));
-        //for (int i=0; i < value.count(); ++i)
-        //{
-            //if (value.at(i).indexOf("Latitude")!=-1)
-             //{
-                //item_spos=i;
-                //break;
-             //}
-        //}
-        QString lat=value.at(2);
-        int k=lat.indexOf(":");
-        lat=lat.right(lat.count()-(k+2));
-        QString lon=value.at(3);
-        k=lon.indexOf(":");
-        lon=lon.right(lon.count()-(k+2));
-        QString ele=value.at(4);
-        k=ele.indexOf(":");
-        ele=ele.right(ele.count()-(k+2));
-        QString date=value.at(0);
-        k=date.indexOf(":");
-        date=date.right(date.count()-(k+2));
-        QString time=value.at(1);
-        k=time.indexOf(":");
-        time=time.right(time.count()-(k+2));
-        QString time_gpx= date + "T" + time + "Z";
-        //if ((lat.count() - (lat.indexOf(".")+1)) >= 3 && (lon.count() - (lon.indexOf(".")+1)) >= 3)
-        if (ele!="nan")
+        if (line=="newtrack")
         {
-            xmlWriter.writeStartElement("trkpt");
-            xmlWriter.writeAttribute("lat",lat);
-            xmlWriter.writeAttribute("lon",lon);
-            xmlWriter.writeStartElement("ele");
-            xmlWriter.writeCharacters(ele);
-            xmlWriter.writeEndElement();
-            xmlWriter.writeStartElement("time");
-            xmlWriter.writeCharacters(time_gpx);
-            xmlWriter.writeEndElement();
-            xmlWriter.writeEndElement();
+            if (tloglines > 1)
+            {
+                xmlWriter.writeEndElement();
+                xmlWriter.writeStartElement("trk");
+            }
+        }
+        else
+        {
+            QStringList value = line.split(QRegExp(";"));
+            QString lat=value.at(2);
+            int k=lat.indexOf(":");
+            lat=lat.right(lat.count()-(k+2));
+            QString lon=value.at(3);
+            k=lon.indexOf(":");
+            lon=lon.right(lon.count()-(k+2));
+            QString ele=value.at(4);
+            k=ele.indexOf(":");
+            ele=ele.right(ele.count()-(k+2));
+            QString date=value.at(0);
+            k=date.indexOf(":");
+            date=date.right(date.count()-(k+2));
+            QString time=value.at(1);
+            k=time.indexOf(":");
+            time=time.right(time.count()-(k+2));
+            QString time_gpx= date + "T" + time + "Z";
+            if (ele!="nan")
+            {
+                tgpxlines++;
+                if (tgpxlines > 1) update(QString::number(tgpxlines) + "/" + QString::number(tloglines));
+                else cout << tgpxlines << "/" << tloglines;
+                xmlWriter.writeStartElement("trkpt");
+                xmlWriter.writeAttribute("lat",lat);
+                xmlWriter.writeAttribute("lon",lon);
+                xmlWriter.writeStartElement("ele");
+                xmlWriter.writeCharacters(ele);
+                xmlWriter.writeEndElement();
+                xmlWriter.writeStartElement("time");
+                xmlWriter.writeCharacters(time_gpx);
+                xmlWriter.writeEndElement();
+                xmlWriter.writeEndElement();
+            }
         }
     }
     xmlWriter.writeEndElement();
     xmlWriter.writeEndDocument();
     logfile.close();
     file.close();
-    qDebug() << "finished";
+    //QTextStream cout(stdout);
+    cout << "\33[2K\r";
+    cout << tgpxlines << "/" << tloglines << endl;
+    qDebug() << "..finished";
 }
 
 void GpsPos::quit(QString input)
@@ -325,5 +343,15 @@ void GpsPos::quit(QString input)
         if (log_method=="gpx") writegpxdata();
         emit finished();
     }
+    else if (input=="t")
+    {
+        writelogfile("newtrack");
+    }
+}
 
+void GpsPos::update(QString status)
+{
+    QTextStream cout(stdout);
+    cout << "\33[2K\r";
+    cout << status;
 }
