@@ -15,8 +15,9 @@ class GpsPos : public QObject
     Q_OBJECT
 public:
     GpsPos(QObject *parent = 0);
+    GpsPos(QObject *parent = 0, QString logmethod="none");
     GpsPos(QObject *parent = 0, bool fout=true, QString posm="all", bool date=false, bool time=false);
-    GpsPos(QObject *parent = 0, int runs=-1, int limit=0, bool lastkv=true, bool showsat=false, bool fout=false, QString posm="onlysat", int interval=0, bool date=false, bool time=false, QString logmethod="none");
+    GpsPos(QObject *parent = 0, int runs=-1, int limit=0, bool lastkv=true, bool showsat=false, bool fout=false, QString posm="onlysat", int interval=0, bool date=false, bool time=false, QString logmethod="none", bool newtrack=false);
     int g_run;
     int g_runs;
     
@@ -29,6 +30,7 @@ public slots:
     void satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &satellites);
     void viewSatelliteInfo();
     void quit(QString input);
+    void update(QString status);
 private:
     void lastknownposition(const QGeoPositionInfo &lastpos);
     void writelogfile(QString line);
