@@ -42,11 +42,12 @@ int main(int argc, char *argv[])
         if (QArgByKey("runs",'=').toInt()!=0) myMain.g_runs = QArgByKey("runs",'=').toInt();
         else myMain.g_runs=-1;
         myMain.g_limit = QArgByKey("limit",'=').toInt();
-        myMain.g_sat  = qApp->arguments().contains("--sat");
-        myMain.g_fout  = qApp->arguments().contains("--fout");
-        myMain.g_lknv  = qApp->arguments().contains("--lknv");
-        myMain.g_date  = qApp->arguments().contains("--date");
-        myMain.g_time  = qApp->arguments().contains("--time");
+        myMain.g_sat = qApp->arguments().contains("--sat");
+        myMain.g_fout = qApp->arguments().contains("--fout");
+        myMain.g_lknv = qApp->arguments().contains("--lknv");
+        myMain.g_date = qApp->arguments().contains("--date");
+        myMain.g_time = qApp->arguments().contains("--time");
+        myMain.g_newtrack = qApp->arguments().contains("--newtrack");
         myMain.g_interval = QArgByKey("intval",'=').toInt();
         myMain.g_del = qApp->arguments().contains("--del");
         if (QArgByKey("log",'=').toLatin1()!="") myMain.g_log = QArgByKey("log",'=').toLatin1();
@@ -62,7 +63,7 @@ int main(int argc, char *argv[])
         {
             QTextStream cout(stdout);
             cout << endl;
-            cout << "gpscon v0.0.6 by halftux" << endl << endl;
+            cout << "gpscon v0.0.7 by halftux" << endl << endl;
             cout << "Options:" << endl;
             cout << "--------" << endl;
             cout << "  [--help] help output" << endl;
@@ -70,15 +71,17 @@ int main(int argc, char *argv[])
             cout << "  [limit=integer] accuracy vert/hori < limit 1x and quit" << endl;
             cout << "  [posm=string]Position method: nonesat / all / onlysat" << endl;
             cout << "  [interval=integer] update interval" << endl;
-            cout << "  [log=string] txt/gpx" << endl;
+            cout << "  [log=string] txt/gpx/log2gpx" << endl;
             cout << "  [--del] deleting log files" << endl;
             cout << "  [--sat] with satellite output" << endl;
             cout << "  [--fout] full position output" << endl;
             cout << "  [--date] date output" << endl;
             cout << "  [--time] time output" << endl;
+            cout << "  [--newtrack] mark in log file" << endl;
             cout << "  [--lknv] output lastknownposition (qdebug)" << endl << endl;
             cout << "Without runs or limit option the app is in endless loop." << endl;
             cout << "You can exit with: x+[enter]." << endl;
+            cout << "You can mark a newtrack with: t+[enter]." << endl;
 
             QTimer::singleShot(10, &myMain, SLOT(quit()));
         }
